/*
	This is a classical Hello program
	to test java2html.

	to have an html translation type

		java2html --input Hello.java --output Hello.html
		java2html < Hello.java > Hello.html

        or type java2html --help for options list

	written by
	Lorenzo Bettini <bettini@gnu.org>
	http://w3.newnet.it/bettini
	http://www.gnu.org/software/java2html
 */

import java.io.* ;

public class Hello {
    int foo = 1998 ;
    boolean b ;
    Integer i = null ;
    char c = '\'', d = 'n', e = '\\' ;
    String xml = "<tag attr=\"value\">&auml;</tag>", foo2 = "\\" ;
    
    public static void main( String args[] ) {
	// just some greetings ;-)  /*
	System.out.println( "Hello from java2html :-)" ) ;
	System.out.println( "\tby Lorenzo Bettini" ) ;
	System.out.println( "\tlorenzo.bettini@penteres.it" ) ;
        //System.out.println( "bye bye... :-D" ) ; // see you soon
    }
}
